@@ -225,6 +225,17 @@ class clLocale:
 
 class varsShare:
     """Share methods and attributs for fill vars methods"""
+    
+    ipdig = "[%s-9]|(?:1[0-9]|[1-9])[0-9]|2[0-4][0-9]|25[0-%s]"
+    ipnet = "[1-9]|[12][0-9]|3[012]"
+    ipdigs = { 'dig1_254' : ipdig % (1,4), 'dig0_254' : ipdig % (0,4),
+               'dig0_255' : ipdig % (0,5), }
+    ipaddr = "(%(dig1_254)s)\.(%(dig0_254)s)\.(%(dig0_254)s)\.(%(dig1_254)s)"%\
+                ipdigs
+    ipaddr_net = "%(ipaddr)s/(%(ipnet)s)"%{'ipaddr':ipaddr,'ipnet':ipnet}
+
+    dictNetworkManagers = {"openrc":"sys-apps/openrc",
+                           "networkmanager":"net-misc/networkmanager"}
 
     dictLinuxName = {"CLD":"Calculate Linux Desktop",
                      "CLDX":"Calculate Linux Desktop",
