@@ -15,7 +15,12 @@
 #  limitations under the License.
 
 import os
-from ldap import LDAPError, MOD_REPLACE, MOD_ADD, SCOPE_SUBTREE, SCOPE_ONELEVEL
+from mod import mod_ldap
+import sys
+sys.modules['mod_ldap'] = mod_ldap
+
+from mod_ldap import LDAPError, MOD_REPLACE, MOD_ADD, SCOPE_SUBTREE,\
+                     SCOPE_ONELEVEL
 from ldif import LDIFParser, LDIFWriter
 import  cStringIO, StringIO
 from cl_utils import _error
